var searchData=
[
  ['spa_5fatob_0',['spa_atob',['../group__spa__string.html#ga16da26e2202a32c64061f92dec72dfc5',1,'string.h']]],
  ['spa_5fatod_1',['spa_atod',['../group__spa__string.html#ga0b03d1967a0ee32027c1efb16fec49de',1,'string.h']]],
  ['spa_5fatof_2',['spa_atof',['../group__spa__string.html#gace4942742ce246641a3cb3b4b2540e05',1,'string.h']]],
  ['spa_5fatoi32_3',['spa_atoi32',['../group__spa__string.html#ga6ddf76d4003737cda2ba9b160aa8dfa8',1,'string.h']]],
  ['spa_5fatoi64_4',['spa_atoi64',['../group__spa__string.html#ga1f07c2f2d56ba170bf23d472153494e5',1,'string.h']]],
  ['spa_5fatou32_5',['spa_atou32',['../group__spa__string.html#ga2aedff000d734290adf11899c5fcb896',1,'string.h']]],
  ['spa_5fatou64_6',['spa_atou64',['../group__spa__string.html#ga0b9d09a3a4f68c4a5e55e350caeb67fb',1,'string.h']]],
  ['spa_5fbuffer_5falloc_5farray_7',['spa_buffer_alloc_array',['../group__spa__buffer.html#ga19c6e5afa926fbda88e8b236df740356',1,'alloc.h']]],
  ['spa_5fbuffer_5falloc_5ffill_5finfo_8',['spa_buffer_alloc_fill_info',['../group__spa__buffer.html#ga78c4855fa1f977a81253c5fb56f3ca19',1,'alloc.h']]],
  ['spa_5fbuffer_5falloc_5flayout_9',['spa_buffer_alloc_layout',['../group__spa__buffer.html#ga7507cafea4ff7545fa7b1ce68a91adde',1,'alloc.h']]],
  ['spa_5fbuffer_5falloc_5flayout_5farray_10',['spa_buffer_alloc_layout_array',['../group__spa__buffer.html#ga890344a4b76e476910fde107efe427dc',1,'alloc.h']]],
  ['spa_5fbuffer_5ffind_5fmeta_11',['spa_buffer_find_meta',['../group__spa__buffer.html#gaa9a9f6e02fb1ecf289e8d647be84770d',1,'buffer.h']]],
  ['spa_5fbuffer_5ffind_5fmeta_5fdata_12',['spa_buffer_find_meta_data',['../group__spa__buffer.html#ga9660cb2a403a7e57860cf739396d9bf5',1,'buffer.h']]],
  ['spa_5fchoice_5ffrom_5fid_13',['spa_choice_from_id',['../group__spa__pod.html#ga7b7954e6302929958069d1eed005ab9b',1,'builder.h']]],
  ['spa_5fdbus_5fget_5fconnection_14',['spa_dbus_get_connection',['../group__spa__dbus.html#gacacb7fc6455e98adad9407e290172246',1,'dbus.h']]],
  ['spa_5fdebug_5fbuffer_15',['spa_debug_buffer',['../group__spa__debug.html#ga38094276cb4dfb2190710683f4edc139',1,'buffer.h']]],
  ['spa_5fdebug_5fdict_16',['spa_debug_dict',['../group__spa__debug.html#ga17e8a8e1fb9113f5add80d0b1cfe9602',1,'dict.h']]],
  ['spa_5fdebug_5fformat_17',['spa_debug_format',['../group__spa__debug.html#ga0c0aff43e13b4501952801fa3be7b1b7',1,'format.h']]],
  ['spa_5fdebug_5fformat_5fvalue_18',['spa_debug_format_value',['../group__spa__debug.html#gaeec0bfa08b41f3002b60ed2e997cabbe',1,'format.h']]],
  ['spa_5fdebug_5flog_5flog_19',['spa_debug_log_log',['../group__spa__debug.html#ga8bb3edd099bef82423cee5eff879c339',1,'log.h']]],
  ['spa_5fdebug_5fmem_20',['spa_debug_mem',['../group__spa__debug.html#gae0fd7bbdbaad907ad5b923053f888dca',1,'mem.h']]],
  ['spa_5fdebug_5fpod_21',['spa_debug_pod',['../group__spa__debug.html#ga43da221712a4457ff34457555d39b214',1,'pod.h']]],
  ['spa_5fdebug_5fpod_5fvalue_22',['spa_debug_pod_value',['../group__spa__debug.html#gaa00cdef782319e1a9ae738ffb9422506',1,'pod.h']]],
  ['spa_5fdebug_5fport_5finfo_23',['spa_debug_port_info',['../group__spa__debug.html#ga26f0007da5add3060d00672939508d55',1,'node.h']]],
  ['spa_5fdebug_5fstrbuf_5fformat_5fvalue_24',['spa_debug_strbuf_format_value',['../group__spa__debug.html#gaef7cbb7d8a18d32656a9149cd4fdfd6d',1,'format.h']]],
  ['spa_5fdebug_5ftype_5ffind_25',['spa_debug_type_find',['../group__spa__debug.html#ga4b2e0edb1afe21a398be311ab6bde5b9',1,'types.h']]],
  ['spa_5fdebug_5ftype_5ffind_5fname_26',['spa_debug_type_find_name',['../group__spa__debug.html#ga8907dcd66c24ffc68f2d328111428936',1,'types.h']]],
  ['spa_5fdebug_5ftype_5ffind_5fshort_27',['spa_debug_type_find_short',['../group__spa__debug.html#gac0431ebc7981b41690e6356925bcc954',1,'types.h']]],
  ['spa_5fdebug_5ftype_5ffind_5fshort_5fname_28',['spa_debug_type_find_short_name',['../group__spa__debug.html#ga8ad92675783ea166fc2ea34dad54b75a',1,'types.h']]],
  ['spa_5fdebug_5ftype_5ffind_5ftype_29',['spa_debug_type_find_type',['../group__spa__debug.html#ga43407166bdc04c3822b66257581fec18',1,'types.h']]],
  ['spa_5fdebug_5ftype_5ffind_5ftype_5fshort_30',['spa_debug_type_find_type_short',['../group__spa__debug.html#gac6f960544afa686154bfebae8c42406b',1,'types.h']]],
  ['spa_5fdebug_5ftype_5fshort_5fname_31',['spa_debug_type_short_name',['../group__spa__debug.html#ga894c39341a4e23d74318af04868a71df',1,'types.h']]],
  ['spa_5fdebugc_5fbuffer_32',['spa_debugc_buffer',['../group__spa__debug.html#ga95e569a17a18eab8f646974d0b2cc136',1,'buffer.h']]],
  ['spa_5fdebugc_5fdict_33',['spa_debugc_dict',['../group__spa__debug.html#ga6b44755735f4fdcce858fa6f97594b65',1,'dict.h']]],
  ['spa_5fdebugc_5fformat_34',['spa_debugc_format',['../group__spa__debug.html#ga5eb6d7ec8b97e55331c9297a581800a5',1,'format.h']]],
  ['spa_5fdebugc_5fmem_35',['spa_debugc_mem',['../group__spa__debug.html#gafaccba3f44098f680e755ad34b421de0',1,'mem.h']]],
  ['spa_5fdebugc_5fpod_36',['spa_debugc_pod',['../group__spa__debug.html#ga3e6c9fbc3e47f47500bf59145a8baadb',1,'pod.h']]],
  ['spa_5fdebugc_5fpod_5fvalue_37',['spa_debugc_pod_value',['../group__spa__debug.html#gac394fa61f7506be415fd8c0b6e422c6a',1,'pod.h']]],
  ['spa_5fdebugc_5fport_5finfo_38',['spa_debugc_port_info',['../group__spa__debug.html#gafb77a961ae0c0be0034f2a1b4f264ee9',1,'node.h']]],
  ['spa_5fdevice_5fenum_5fparams_5fsync_39',['spa_device_enum_params_sync',['../group__spa__device.html#gac5d87bd2bc51abe0c370198371428f6f',1,'utils.h']]],
  ['spa_5fdict_5fitem_5fcompare_40',['spa_dict_item_compare',['../group__spa__dict.html#gabdc26b8d87710308053eb5175b747ef7',1,'dict.h']]],
  ['spa_5fdict_5flookup_41',['spa_dict_lookup',['../group__spa__dict.html#gad7ed7458879952ce549d716d6c8795b2',1,'dict.h']]],
  ['spa_5fdict_5flookup_5fitem_42',['spa_dict_lookup_item',['../group__spa__dict.html#gad5dd086561daa9a087ae5692cef9f472',1,'dict.h']]],
  ['spa_5fdict_5fqsort_43',['spa_dict_qsort',['../group__spa__dict.html#ga9f7b5a7c12bdbfda65275270dcb72abd',1,'dict.h']]],
  ['spa_5fdtoa_44',['spa_dtoa',['../group__spa__string.html#gae9be2db04a7f11c3ff07b78f635c9fe3',1,'string.h']]],
  ['spa_5fformat_5farg_5ffunc_45',['SPA_FORMAT_ARG_FUNC',['../group__pw__gettext.html#ga13fa16d21c2d32f812f8cb071b6d8794',1,'i18n.h']]],
  ['spa_5fformat_5faudio_5faac_5fbuild_46',['spa_format_audio_aac_build',['../group__spa__param.html#ga34f2853a6e1fb9c8600cd3675f48376e',1,'aac-utils.h']]],
  ['spa_5fformat_5faudio_5faac_5fparse_47',['spa_format_audio_aac_parse',['../group__spa__param.html#ga13979f552d56ea0efe5cb052b6123670',1,'aac-utils.h']]],
  ['spa_5fformat_5faudio_5falac_5fbuild_48',['spa_format_audio_alac_build',['../group__spa__param.html#ga07f4ed9cdd3b61861a9d8faa69dbeb44',1,'alac-utils.h']]],
  ['spa_5fformat_5faudio_5falac_5fparse_49',['spa_format_audio_alac_parse',['../group__spa__param.html#gabf14304a778fe0b2cd4379f187a85144',1,'alac-utils.h']]],
  ['spa_5fformat_5faudio_5famr_5fbuild_50',['spa_format_audio_amr_build',['../group__spa__param.html#gaadc8f3d595aa47b00136657fa28a7adc',1,'amr-utils.h']]],
  ['spa_5fformat_5faudio_5famr_5fparse_51',['spa_format_audio_amr_parse',['../group__spa__param.html#ga4b41f63cb5b094caa8fa328bdac052e5',1,'amr-utils.h']]],
  ['spa_5fformat_5faudio_5fape_5fbuild_52',['spa_format_audio_ape_build',['../group__spa__param.html#ga304470cf722efd8b2b0617268235c322',1,'ape-utils.h']]],
  ['spa_5fformat_5faudio_5fape_5fparse_53',['spa_format_audio_ape_parse',['../group__spa__param.html#ga33594ef1acef5373cd2463428851b161',1,'ape-utils.h']]],
  ['spa_5fformat_5faudio_5fbuild_54',['spa_format_audio_build',['../group__spa__param.html#ga80840b57eb4cd20c97eb1ea5b00d0a72',1,'format-utils.h']]],
  ['spa_5fformat_5faudio_5fdsd_5fbuild_55',['spa_format_audio_dsd_build',['../group__spa__param.html#ga9b6e3523b3f2fbac89443d1e8346bc14',1,'dsd-utils.h']]],
  ['spa_5fformat_5faudio_5fdsd_5fparse_56',['spa_format_audio_dsd_parse',['../group__spa__param.html#ga3e1f116b69a0cdb656031d91b0bd725c',1,'dsd-utils.h']]],
  ['spa_5fformat_5faudio_5fdsp_5fbuild_57',['spa_format_audio_dsp_build',['../group__spa__param.html#ga4c170ef62a329e09137ad722cdcbf804',1,'dsp-utils.h']]],
  ['spa_5fformat_5faudio_5fdsp_5fparse_58',['spa_format_audio_dsp_parse',['../group__spa__param.html#ga5435b922d29ba003263c9ca02005b39f',1,'dsp-utils.h']]],
  ['spa_5fformat_5faudio_5fflac_5fbuild_59',['spa_format_audio_flac_build',['../group__spa__param.html#ga63a7422e18d0fbb82827ffbe87e87b43',1,'flac-utils.h']]],
  ['spa_5fformat_5faudio_5fflac_5fparse_60',['spa_format_audio_flac_parse',['../group__spa__param.html#ga615b93798d7cd2c4efdc1e8b98ad02b7',1,'flac-utils.h']]],
  ['spa_5fformat_5faudio_5fiec958_5fbuild_61',['spa_format_audio_iec958_build',['../group__spa__param.html#ga07fe0ccce4b013711eb1ebd62ddcc4d4',1,'iec958-utils.h']]],
  ['spa_5fformat_5faudio_5fiec958_5fparse_62',['spa_format_audio_iec958_parse',['../group__spa__param.html#ga003b5b298a7a164560c3e70a15bcdbb4',1,'iec958-utils.h']]],
  ['spa_5fformat_5faudio_5fmp3_5fbuild_63',['spa_format_audio_mp3_build',['../group__spa__param.html#gaf740e94462b50d7fc74500d76c1b55d4',1,'mp3-utils.h']]],
  ['spa_5fformat_5faudio_5fmp3_5fparse_64',['spa_format_audio_mp3_parse',['../group__spa__param.html#ga05d8867ffd6e183174c0be1eba513050',1,'mp3-utils.h']]],
  ['spa_5fformat_5faudio_5fparse_65',['spa_format_audio_parse',['../group__spa__param.html#gae11173033fad59ffa4a21773bb39be3d',1,'format-utils.h']]],
  ['spa_5fformat_5faudio_5fra_5fbuild_66',['spa_format_audio_ra_build',['../group__spa__param.html#ga3c9b746ec61d72b0eec66a8aeb212949',1,'ra-utils.h']]],
  ['spa_5fformat_5faudio_5fra_5fparse_67',['spa_format_audio_ra_parse',['../group__spa__param.html#gafd4a1ca08a83513d697c677922978638',1,'ra-utils.h']]],
  ['spa_5fformat_5faudio_5fraw_5fbuild_68',['spa_format_audio_raw_build',['../group__spa__param.html#ga1c67d427a98385603b71dff182cac97a',1,'raw-utils.h']]],
  ['spa_5fformat_5faudio_5fraw_5fparse_69',['spa_format_audio_raw_parse',['../group__spa__param.html#ga1e59ac8855dc2de8b982743866ca6a1e',1,'raw-utils.h']]],
  ['spa_5fformat_5faudio_5fvorbis_5fbuild_70',['spa_format_audio_vorbis_build',['../group__spa__param.html#ga5b1a427dcfc1bf70ffc5bc62fd02c0d9',1,'vorbis-utils.h']]],
  ['spa_5fformat_5faudio_5fvorbis_5fparse_71',['spa_format_audio_vorbis_parse',['../group__spa__param.html#gaebd26a2e1cd1572db133a33ff75762b2',1,'vorbis-utils.h']]],
  ['spa_5fformat_5faudio_5fwma_5fbuild_72',['spa_format_audio_wma_build',['../group__spa__param.html#ga7c2e71fbca3695bfda6b8b4207f59714',1,'wma-utils.h']]],
  ['spa_5fformat_5faudio_5fwma_5fparse_73',['spa_format_audio_wma_parse',['../group__spa__param.html#ga6c89bf89ceac8b423aa55ea0289d0b03',1,'wma-utils.h']]],
  ['spa_5fformat_5fparse_74',['spa_format_parse',['../group__spa__param.html#ga1cbd069826f34cfa5521bbd05db5da5c',1,'format-utils.h']]],
  ['spa_5fformat_5fvideo_5fdsp_5fbuild_75',['spa_format_video_dsp_build',['../group__spa__param.html#ga482d0bd91327365c2838774cf4ed7299',1,'dsp-utils.h']]],
  ['spa_5fformat_5fvideo_5fdsp_5fparse_76',['spa_format_video_dsp_parse',['../group__spa__param.html#ga8057ff5c7d195cf1bf8b051b695d33da',1,'dsp-utils.h']]],
  ['spa_5fformat_5fvideo_5fh264_5fbuild_77',['spa_format_video_h264_build',['../group__spa__param.html#ga2b70ce7aad3da855e47400a83c53a383',1,'h264-utils.h']]],
  ['spa_5fformat_5fvideo_5fh264_5fparse_78',['spa_format_video_h264_parse',['../group__spa__param.html#gacbc7244aeecec7e55adcbae20eda9563',1,'h264-utils.h']]],
  ['spa_5fformat_5fvideo_5fmjpg_5fbuild_79',['spa_format_video_mjpg_build',['../group__spa__param.html#gab522dee812b7343a5101199b7157f471',1,'mjpg-utils.h']]],
  ['spa_5fformat_5fvideo_5fmjpg_5fparse_80',['spa_format_video_mjpg_parse',['../group__spa__param.html#gad004acb2d123e441451b541253f6ca75',1,'mjpg-utils.h']]],
  ['spa_5fformat_5fvideo_5fraw_5fbuild_81',['spa_format_video_raw_build',['../group__spa__param.html#ga86952e16eacf1c65b997ad7d8f8fca65',1,'raw-utils.h']]],
  ['spa_5fformat_5fvideo_5fraw_5fparse_82',['spa_format_video_raw_parse',['../group__spa__param.html#gaa1c7e098c6b84b43a31b48bd65dbbb53',1,'raw-utils.h']]],
  ['spa_5fgraph_5ffinish_83',['spa_graph_finish',['../group__spa__graph.html#ga834421fadbb869fc8faad4532e866f7f',1,'graph.h']]],
  ['spa_5fgraph_5finit_84',['spa_graph_init',['../group__spa__graph.html#ga258938261c43d11f61333a77be0a3324',1,'graph.h']]],
  ['spa_5fgraph_5flink_5fadd_85',['spa_graph_link_add',['../group__spa__graph.html#ga1861db81168670b30eccd19414f807c5',1,'graph.h']]],
  ['spa_5fgraph_5flink_5fremove_86',['spa_graph_link_remove',['../group__spa__graph.html#gadba31399bd4eccf65b5dbc8bcf378065',1,'graph.h']]],
  ['spa_5fgraph_5flink_5fsignal_5fgraph_87',['spa_graph_link_signal_graph',['../group__spa__graph.html#gaa1eec75ae44307a384b5f2d4d869bbc6',1,'graph.h']]],
  ['spa_5fgraph_5flink_5fsignal_5fnode_88',['spa_graph_link_signal_node',['../group__spa__graph.html#gaeea00171bcd084512a1e819c84247e27',1,'graph.h']]],
  ['spa_5fgraph_5flink_5ftrigger_89',['spa_graph_link_trigger',['../group__spa__graph.html#ga6f85122f34e53bfc806a04c9cb532fce',1,'graph.h']]],
  ['spa_5fgraph_5fnode_5fadd_90',['spa_graph_node_add',['../group__spa__graph.html#ga277f9def5e8ae6b1348c4d64ebd2c922',1,'graph.h']]],
  ['spa_5fgraph_5fnode_5fimpl_5fprocess_91',['spa_graph_node_impl_process',['../group__spa__graph.html#ga6a207442ebc3f91200474b2975f46a81',1,'graph.h']]],
  ['spa_5fgraph_5fnode_5fimpl_5freuse_5fbuffer_92',['spa_graph_node_impl_reuse_buffer',['../group__spa__graph.html#ga28ea8a94abe2994c203feb04333e2981',1,'graph.h']]],
  ['spa_5fgraph_5fnode_5fimpl_5fsub_5fprocess_93',['spa_graph_node_impl_sub_process',['../group__spa__graph.html#ga3faeab1caafb66e25605f03fff8375e0',1,'graph.h']]],
  ['spa_5fgraph_5fnode_5finit_94',['spa_graph_node_init',['../group__spa__graph.html#ga819ea10875f897aae380857243fc30a3',1,'graph.h']]],
  ['spa_5fgraph_5fnode_5fremove_95',['spa_graph_node_remove',['../group__spa__graph.html#ga8845237cef2bd684bb2f0de82f8f1019',1,'graph.h']]],
  ['spa_5fgraph_5fnode_5fset_5fcallbacks_96',['spa_graph_node_set_callbacks',['../group__spa__graph.html#ga0dbf44db8504bcb77b7a72e20315d99f',1,'graph.h']]],
  ['spa_5fgraph_5fnode_5fset_5fsubgraph_97',['spa_graph_node_set_subgraph',['../group__spa__graph.html#ga6c74082f35a17d1fb88a392466a5ee53',1,'graph.h']]],
  ['spa_5fgraph_5fnode_5ftrigger_98',['spa_graph_node_trigger',['../group__spa__graph.html#ga58d84e6be0c6eb9928f988c7875ce4be',1,'graph.h']]],
  ['spa_5fgraph_5fport_5fadd_99',['spa_graph_port_add',['../group__spa__graph.html#ga8ed30e4e1d124815203cfe5ba275b460',1,'graph.h']]],
  ['spa_5fgraph_5fport_5finit_100',['spa_graph_port_init',['../group__spa__graph.html#ga83090d992846d8ccf39e6e8ba2371bc8',1,'graph.h']]],
  ['spa_5fgraph_5fport_5flink_101',['spa_graph_port_link',['../group__spa__graph.html#gaac674e745b114565e44f5a451df13f52',1,'graph.h']]],
  ['spa_5fgraph_5fport_5fremove_102',['spa_graph_port_remove',['../group__spa__graph.html#ga234972c464dadf002ac0c7fb12683668',1,'graph.h']]],
  ['spa_5fgraph_5fport_5funlink_103',['spa_graph_port_unlink',['../group__spa__graph.html#gafae076c37db9c913ce0afb6cd285c6ff',1,'graph.h']]],
  ['spa_5fgraph_5frun_104',['spa_graph_run',['../group__spa__graph.html#ga3707f5819de7baf600d84a452971e0e9',1,'graph.h']]],
  ['spa_5fgraph_5fstate_5freset_105',['spa_graph_state_reset',['../group__spa__graph.html#ga0fb5b4561d5898fa95b2bc0fd43d7c34',1,'graph.h']]],
  ['spa_5fhandle_5ffactory_5fenum_106',['spa_handle_factory_enum',['../group__spa__handle.html#gaec2d5563ec9ea8d6c4155ca6525ae3b7',1,'plugin.h']]],
  ['spa_5fhook_5flist_5fappend_107',['spa_hook_list_append',['../group__spa__hooks.html#ga4f7f50596d9e2b4e3146ed89444ab8b2',1,'hook.h']]],
  ['spa_5fhook_5flist_5fclean_108',['spa_hook_list_clean',['../group__spa__hooks.html#gacb30a0a53954eed2af8041a1882eef15',1,'hook.h']]],
  ['spa_5fhook_5flist_5finit_109',['spa_hook_list_init',['../group__spa__hooks.html#ga9fb6df7a8c2a772b0cc39f81bc0eec03',1,'hook.h']]],
  ['spa_5fhook_5flist_5fis_5fempty_110',['spa_hook_list_is_empty',['../group__spa__hooks.html#ga184c539864a808c984c21f052e2ac085',1,'hook.h']]],
  ['spa_5fhook_5flist_5fisolate_111',['spa_hook_list_isolate',['../group__spa__hooks.html#gae70f84c0eb2bae8f5d08eb694969dd40',1,'hook.h']]],
  ['spa_5fhook_5flist_5fjoin_112',['spa_hook_list_join',['../group__spa__hooks.html#ga63c54fcf4a4073e230e656f3275ebaea',1,'hook.h']]],
  ['spa_5fhook_5flist_5fprepend_113',['spa_hook_list_prepend',['../group__spa__hooks.html#gacbc74f9ceab3dc7c5d6d8c3eca6a41e5',1,'hook.h']]],
  ['spa_5fhook_5fremove_114',['spa_hook_remove',['../group__spa__hooks.html#gab5d20379dc8a8a17e58631045e3f6323',1,'hook.h']]],
  ['spa_5fi18n_5fntext_115',['spa_i18n_ntext',['../group__spa__i18n.html#gaa4c021574498780906bcc3f2958cc23f',1,'i18n.h']]],
  ['spa_5fi18n_5ftext_116',['spa_i18n_text',['../group__spa__i18n.html#gafe48fd94d55ba3db8f10fb1550ec79c8',1,'i18n.h']]],
  ['spa_5fjson_5fcontainer_5flen_117',['spa_json_container_len',['../group__spa__json.html#ga04a8b54928642e8bc49077d7f26e57a5',1,'json.h']]],
  ['spa_5fjson_5fencode_5fstring_118',['spa_json_encode_string',['../group__spa__json.html#gab03680b46f934bdc18755d2156077cf1',1,'json.h']]],
  ['spa_5fjson_5fenter_119',['spa_json_enter',['../group__spa__json.html#ga54e9a5e2c169224c8ae8953135290505',1,'json.h']]],
  ['spa_5fjson_5fenter_5farray_120',['spa_json_enter_array',['../group__spa__json.html#gad27e11f0d644f60840cb42bdcc370412',1,'json.h']]],
  ['spa_5fjson_5fenter_5fcontainer_121',['spa_json_enter_container',['../group__spa__json.html#ga4dbbb0d8d43216c23d20b08be1650437',1,'json.h']]],
  ['spa_5fjson_5fenter_5fobject_122',['spa_json_enter_object',['../group__spa__json.html#ga6502b3572751902a364273b0cdaa13c4',1,'json.h']]],
  ['spa_5fjson_5fformat_5ffloat_123',['spa_json_format_float',['../group__spa__json.html#ga7c080249c08879b0576e5225a67fde7e',1,'json.h']]],
  ['spa_5fjson_5fget_5fbool_124',['spa_json_get_bool',['../group__spa__json.html#ga910d92b40deefb1451ddcdee9b96c243',1,'json.h']]],
  ['spa_5fjson_5fget_5ffloat_125',['spa_json_get_float',['../group__spa__json.html#gad655166a86f6b9b79fb480603bf63ec3',1,'json.h']]],
  ['spa_5fjson_5fget_5fint_126',['spa_json_get_int',['../group__spa__json.html#ga604d3512668501ff1a1d5897c0208416',1,'json.h']]],
  ['spa_5fjson_5fget_5fstring_127',['spa_json_get_string',['../group__spa__json.html#ga6864ecec42015a48aa8991d6a2c8d6fa',1,'json.h']]],
  ['spa_5fjson_5finit_128',['spa_json_init',['../group__spa__json.html#gacda21b833e3e2e8ed1b8bc42bf017ee9',1,'json.h']]],
  ['spa_5fjson_5fis_5farray_129',['spa_json_is_array',['../group__spa__json.html#ga8e5fa24c312810edffc063169e55497d',1,'json.h']]],
  ['spa_5fjson_5fis_5fbool_130',['spa_json_is_bool',['../group__spa__json.html#ga6c02b51e71c406e5b7f014858bdf579b',1,'json.h']]],
  ['spa_5fjson_5fis_5fcontainer_131',['spa_json_is_container',['../group__spa__json.html#gacc0420e669d2d9ab67bf711a63373026',1,'json.h']]],
  ['spa_5fjson_5fis_5ffalse_132',['spa_json_is_false',['../group__spa__json.html#ga5e367b9297cbf21d391f4d1b2ffe4734',1,'json.h']]],
  ['spa_5fjson_5fis_5ffloat_133',['spa_json_is_float',['../group__spa__json.html#ga16c676cb24334b96a9e1eaf0d73ec39f',1,'json.h']]],
  ['spa_5fjson_5fis_5fint_134',['spa_json_is_int',['../group__spa__json.html#gace48d5f93c0be66297f2389175de2ee0',1,'json.h']]],
  ['spa_5fjson_5fis_5fnull_135',['spa_json_is_null',['../group__spa__json.html#ga9110761cf050dd015410b949edd24350',1,'json.h']]],
  ['spa_5fjson_5fis_5fobject_136',['spa_json_is_object',['../group__spa__json.html#gae465abe3ff0170d6b630ead5901fba56',1,'json.h']]],
  ['spa_5fjson_5fis_5fstring_137',['spa_json_is_string',['../group__spa__json.html#ga07e1f5cda4b1894f6165805159d11faa',1,'json.h']]],
  ['spa_5fjson_5fis_5ftrue_138',['spa_json_is_true',['../group__spa__json.html#ga2b070aa36336cbe95ffe1871672ecd70',1,'json.h']]],
  ['spa_5fjson_5fnext_139',['spa_json_next',['../group__spa__json.html#gac6aa5f68834748dc6790cf5dd2ac9401',1,'json.h']]],
  ['spa_5fjson_5fparse_5fbool_140',['spa_json_parse_bool',['../group__spa__json.html#ga62fe1f66450b557cf2c5b5e65a5fcd70',1,'json.h']]],
  ['spa_5fjson_5fparse_5ffloat_141',['spa_json_parse_float',['../group__spa__json.html#ga255f1962c8cb52c861c197533693732c',1,'json.h']]],
  ['spa_5fjson_5fparse_5fhex_142',['spa_json_parse_hex',['../group__spa__json.html#ga588b735c81b1826b44076463ff7bff07',1,'json.h']]],
  ['spa_5fjson_5fparse_5fint_143',['spa_json_parse_int',['../group__spa__json.html#gabc34f55fde305ab5ff6a28d34a642170',1,'json.h']]],
  ['spa_5fjson_5fparse_5fstring_144',['spa_json_parse_string',['../group__spa__json.html#gae51e8d4cc1999ffcc20802cc9e3f8a97',1,'json.h']]],
  ['spa_5fjson_5fparse_5fstringn_145',['spa_json_parse_stringn',['../group__spa__json.html#ga2fe3d2f299b7227b36c93c84c0117f96',1,'json.h']]],
  ['spa_5fjson_5fto_5fpod_146',['spa_json_to_pod',['../group__spa__json__pod.html#ga7904434cb7205e5aa65caa9a7d225e77',1,'json-pod.h']]],
  ['spa_5fjson_5fto_5fpod_5fpart_147',['spa_json_to_pod_part',['../group__spa__json__pod.html#gaffbc97d3a2e34cca3c9735634c2a3013',1,'json-pod.h']]],
  ['spa_5flatency_5fbuild_148',['spa_latency_build',['../group__spa__param.html#ga67fd4b04ffeaa78409011c770e97e2f2',1,'latency-utils.h']]],
  ['spa_5flatency_5finfo_5fcombine_149',['spa_latency_info_combine',['../group__spa__param.html#ga5029c31c3310826708d529cfcd0d829b',1,'latency-utils.h']]],
  ['spa_5flatency_5finfo_5fcombine_5ffinish_150',['spa_latency_info_combine_finish',['../group__spa__param.html#gab36bcbd0f3ed8a1ab3e455e3c068b07e',1,'latency-utils.h']]],
  ['spa_5flatency_5finfo_5fcombine_5fstart_151',['spa_latency_info_combine_start',['../group__spa__param.html#gac0820f0b96a3e203332e3840ad7a9677',1,'latency-utils.h']]],
  ['spa_5flatency_5finfo_5fcompare_152',['spa_latency_info_compare',['../group__spa__param.html#gab7296a16fe3c2ab073f09033ace19b77',1,'latency-utils.h']]],
  ['spa_5flatency_5fparse_153',['spa_latency_parse',['../group__spa__param.html#ga2aaed3eb4497bc4e4df63b9207069e53',1,'latency-utils.h']]],
  ['spa_5flist_5finit_154',['spa_list_init',['../group__spa__list.html#ga731aaed174d63ae6cc01cddde266ed73',1,'list.h']]],
  ['spa_5flist_5finsert_155',['spa_list_insert',['../group__spa__list.html#ga15db195a9509817eb07df421de1b1ffc',1,'list.h']]],
  ['spa_5flist_5finsert_5flist_156',['spa_list_insert_list',['../group__spa__list.html#gafbca4263c0f4f6afba58f226bfb99198',1,'list.h']]],
  ['spa_5flist_5fis_5finitialized_157',['spa_list_is_initialized',['../group__spa__list.html#ga32ec10b38637983ef5347a13e51d6612',1,'list.h']]],
  ['spa_5flist_5fremove_158',['spa_list_remove',['../group__spa__list.html#ga7c4f3862b62ea26df079936f5ebfdacc',1,'list.h']]],
  ['spa_5flog_5fimpl_5flog_159',['spa_log_impl_log',['../group__spa__log.html#ga0f6523b51087c252b5ccf1b68bdce51d',1,'log-impl.h']]],
  ['spa_5flog_5fimpl_5flogt_160',['spa_log_impl_logt',['../group__spa__log.html#ga73863d235426379d73a1defd3191877c',1,'log-impl.h']]],
  ['spa_5flog_5fimpl_5flogtv_161',['spa_log_impl_logtv',['../group__spa__log.html#ga57e9358ebf5d48ede482791857f234a8',1,'log-impl.h']]],
  ['spa_5flog_5fimpl_5flogv_162',['spa_log_impl_logv',['../group__spa__log.html#gac7db20d119aac7855ba0964b7f997456',1,'log-impl.h']]],
  ['spa_5flog_5fimpl_5ftopic_5finit_163',['spa_log_impl_topic_init',['../group__spa__log.html#ga2a153ee3bd5ce9737fc4f7b6e78084f1',1,'log-impl.h']]],
  ['spa_5fmeta_5fend_164',['spa_meta_end',['../group__spa__buffer.html#ga09f7c04cbfa3ccd986c9c78e4056122e',1,'meta.h']]],
  ['spa_5fmeta_5ffirst_165',['spa_meta_first',['../group__spa__buffer.html#ga7ce30cbcea289cbb13c62b406151ac29',1,'meta.h']]],
  ['spa_5fmeta_5fregion_5fis_5fvalid_166',['spa_meta_region_is_valid',['../group__spa__buffer.html#gaa045d6139b26b993d9d4543c9c9a9406',1,'meta.h']]],
  ['spa_5fnode_5fenum_5fparams_5fsync_167',['spa_node_enum_params_sync',['../group__spa__node.html#ga38d51bd4e324b9fa9f1289c8c41ee611',1,'utils.h']]],
  ['spa_5fnode_5fport_5fenum_5fparams_5fsync_168',['spa_node_port_enum_params_sync',['../group__spa__node.html#gaccf324882da5942ac8622af7760bff4d',1,'utils.h']]],
  ['spa_5fplugin_5floader_5fload_169',['spa_plugin_loader_load',['../group__spa__plugin__loader.html#ga85762c2a7fd3d81e45000c392c56b82f',1,'plugin-loader.h']]],
  ['spa_5fplugin_5floader_5funload_170',['spa_plugin_loader_unload',['../group__spa__plugin__loader.html#gaf9dd57a5b0c8889762889183966a6db5',1,'plugin-loader.h']]],
  ['spa_5fpod_5fbuilder_5fadd_171',['spa_pod_builder_add',['../group__spa__pod.html#ga4ed91d7bcbccedf0f26dbd3f563f900b',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5faddv_172',['spa_pod_builder_addv',['../group__spa__pod.html#gaef57db1bd9e4683c0e96dd2d8e4dfc0c',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5farray_173',['spa_pod_builder_array',['../group__spa__pod.html#gac3d904dbfc22fc35a405e4f2b116f79e',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fbool_174',['spa_pod_builder_bool',['../group__spa__pod.html#ga929573f096e90d4aa11d14e1527d2d63',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fbytes_175',['spa_pod_builder_bytes',['../group__spa__pod.html#gab76a5f13f125ca2610906f28e1961b3c',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fchild_176',['spa_pod_builder_child',['../group__spa__pod.html#ga204d1a47391802a5c04f2def9bbe919a',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fcontrol_177',['spa_pod_builder_control',['../group__spa__pod.html#ga7e2695ed7013bdf6791e692e3c726452',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fderef_178',['spa_pod_builder_deref',['../group__spa__pod.html#gaf08245bcd5bb244e6ea3d7520b4a665c',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fdouble_179',['spa_pod_builder_double',['../group__spa__pod.html#ga4059b7055950c4100924cf9bc2b4e23f',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5ffd_180',['spa_pod_builder_fd',['../group__spa__pod.html#ga500437e7eb44b8c952651347fb6c9af9',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5ffloat_181',['spa_pod_builder_float',['../group__spa__pod.html#ga248c1c43ff4e5eb06f40b158e4a0118c',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5ffraction_182',['spa_pod_builder_fraction',['../group__spa__pod.html#ga2077f14c98a8f7061f98099922b7d908',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fframe_183',['spa_pod_builder_frame',['../group__spa__pod.html#ga513238371ee54a3ef16170f0e0837361',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fget_5fstate_184',['spa_pod_builder_get_state',['../group__spa__pod.html#ga85016b1c73cf76d8c4789a6f539ac4ec',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fid_185',['spa_pod_builder_id',['../group__spa__pod.html#ga4e6318d6126ba71bbee8f9abe373705c',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5finit_186',['spa_pod_builder_init',['../group__spa__pod.html#gab989a0cb71f9cd64a9e9e55bdddc8b7b',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fint_187',['spa_pod_builder_int',['../group__spa__pod.html#gab966fee940439f061d88b19064b8b5dd',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5flong_188',['spa_pod_builder_long',['../group__spa__pod.html#gabeeecc8300aa1f563171db73c654b4d0',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fnone_189',['spa_pod_builder_none',['../group__spa__pod.html#ga58eb1d962b1496daa88023eaf54cce30',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fpad_190',['spa_pod_builder_pad',['../group__spa__pod.html#ga6b1922c10ef786d66c9a2177ff10137a',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fpointer_191',['spa_pod_builder_pointer',['../group__spa__pod.html#gaf7da1e4f789a92436cf3bc9c95469ca5',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fpop_192',['spa_pod_builder_pop',['../group__spa__pod.html#ga6ad94cfd9e2816a83763788f032546ae',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fprimitive_193',['spa_pod_builder_primitive',['../group__spa__pod.html#ga7a84af2ae6a8375b73f29337f32c744a',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fprop_194',['spa_pod_builder_prop',['../group__spa__pod.html#ga08615272e6e8633377ecdd5d22aec287',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fpush_195',['spa_pod_builder_push',['../group__spa__pod.html#ga3bd72e84bf9817f0fcc58bc45afe0bfd',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fpush_5farray_196',['spa_pod_builder_push_array',['../group__spa__pod.html#ga7820560083401bab79329a6b3b138c7d',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fpush_5fchoice_197',['spa_pod_builder_push_choice',['../group__spa__pod.html#gab7706385d4c4463bdd28a1885135c3c2',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fpush_5fobject_198',['spa_pod_builder_push_object',['../group__spa__pod.html#gab99db8b4a691fb02158e43a6eac39d96',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fpush_5fsequence_199',['spa_pod_builder_push_sequence',['../group__spa__pod.html#ga5f0935793f667923844cab08ea6f8637',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fpush_5fstruct_200',['spa_pod_builder_push_struct',['../group__spa__pod.html#ga7d41061d62cfb1d25b3d35e35c3566ed',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fraw_201',['spa_pod_builder_raw',['../group__spa__pod.html#gab1e994f1dbe8353d46988c092f87ba37',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fraw_5fpadded_202',['spa_pod_builder_raw_padded',['../group__spa__pod.html#ga61c88157df991f9ae54bbdc174e75e7f',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5frectangle_203',['spa_pod_builder_rectangle',['../group__spa__pod.html#ga21fc64d33bd3695de8dcf1f6f93317ca',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5freserve_5fbytes_204',['spa_pod_builder_reserve_bytes',['../group__spa__pod.html#ga015f21e522057422afcdc3933ae558d2',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5freset_205',['spa_pod_builder_reset',['../group__spa__pod.html#ga51ce89d586f0ebe8b636905fdbd50017',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fset_5fcallbacks_206',['spa_pod_builder_set_callbacks',['../group__spa__pod.html#ga4af1361c985badef6492259d57a50313',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fstring_207',['spa_pod_builder_string',['../group__spa__pod.html#ga1dd09e366646a57e7ff74b2ca56c5e82',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fstring_5flen_208',['spa_pod_builder_string_len',['../group__spa__pod.html#ga6e5334f69fcdb30c819cc2d2042cea4f',1,'builder.h']]],
  ['spa_5fpod_5fbuilder_5fwrite_5fstring_209',['spa_pod_builder_write_string',['../group__spa__pod.html#ga43f673bf5cd77a1a51e272d289c5e9f1',1,'builder.h']]],
  ['spa_5fpod_5fchoice_5ffix_5fdefault_210',['spa_pod_choice_fix_default',['../group__spa__pod.html#ga5e8d9e3e7fbbeff37cb0279160ca0962',1,'filter.h']]],
  ['spa_5fpod_5fcompare_211',['spa_pod_compare',['../group__spa__pod.html#ga887a4f837a5690cc40fe30c8f4461452',1,'compare.h']]],
  ['spa_5fpod_5fcompare_5fvalue_212',['spa_pod_compare_value',['../group__spa__pod.html#ga31a284dcca49f4fcd6f67982b51afacf',1,'compare.h']]],
  ['spa_5fpod_5fcontrol_5ffirst_213',['spa_pod_control_first',['../group__spa__pod.html#gac6e12a691e34645fedf6bf56dc36fe75',1,'iter.h']]],
  ['spa_5fpod_5fcontrol_5fis_5finside_214',['spa_pod_control_is_inside',['../group__spa__pod.html#ga2b2f9467266bb48fb9f6ef72172ad529',1,'iter.h']]],
  ['spa_5fpod_5fcontrol_5fnext_215',['spa_pod_control_next',['../group__spa__pod.html#ga6af158c8b9440c5c5f9b0bbb7cf36625',1,'iter.h']]],
  ['spa_5fpod_5fcopy_216',['spa_pod_copy',['../group__spa__pod.html#gaaf15f086fee08d6cd039b2524177e9b7',1,'builder.h']]],
  ['spa_5fpod_5fcopy_5farray_217',['spa_pod_copy_array',['../group__spa__pod.html#ga694313e53324282f1e5c0c0abfeaee41',1,'iter.h']]],
  ['spa_5fpod_5fcopy_5fstring_218',['spa_pod_copy_string',['../group__spa__pod.html#ga675878397d60084917d134c5882ea7e2',1,'iter.h']]],
  ['spa_5fpod_5ffilter_219',['spa_pod_filter',['../group__spa__pod.html#gaf40f681348bff742f24935a2075ef3bb',1,'filter.h']]],
  ['spa_5fpod_5ffilter_5fflags_5fvalue_220',['spa_pod_filter_flags_value',['../group__spa__pod.html#ga1a7880f8a28a30720da6bb6b636a9a1c',1,'filter.h']]],
  ['spa_5fpod_5ffilter_5fis_5fstep_5fof_221',['spa_pod_filter_is_step_of',['../group__spa__pod.html#ga37b7c8a0ca1e4adafd4670340328d125',1,'filter.h']]],
  ['spa_5fpod_5ffilter_5fpart_222',['spa_pod_filter_part',['../group__spa__pod.html#ga5d676b81bf66a4147c0f52d8ebdd5b5c',1,'filter.h']]],
  ['spa_5fpod_5ffilter_5fprop_223',['spa_pod_filter_prop',['../group__spa__pod.html#ga67f021221aaedced51ab95dd8e7ef895',1,'filter.h']]],
  ['spa_5fpod_5ffind_5fprop_224',['spa_pod_find_prop',['../group__spa__pod.html#ga3b2c9003007b7ea6b84dfa486c37c9bd',1,'iter.h']]],
  ['spa_5fpod_5ffixate_225',['spa_pod_fixate',['../group__spa__pod.html#ga21c7b271eda2c6af65f613f26a95e941',1,'iter.h']]],
  ['spa_5fpod_5ffrom_5fdata_226',['spa_pod_from_data',['../group__spa__pod.html#ga968fa8752e502888664b6a43b00287f0',1,'iter.h']]],
  ['spa_5fpod_5fget_5farray_227',['spa_pod_get_array',['../group__spa__pod.html#ga9cd96f7179e7edcbb4a2385ce48229ad',1,'iter.h']]],
  ['spa_5fpod_5fget_5fbool_228',['spa_pod_get_bool',['../group__spa__pod.html#gab0b7a7f005a8df9b0ca134294925cdca',1,'iter.h']]],
  ['spa_5fpod_5fget_5fbytes_229',['spa_pod_get_bytes',['../group__spa__pod.html#gaf862c079e6d7412d1b9891ef17e4805f',1,'iter.h']]],
  ['spa_5fpod_5fget_5fdouble_230',['spa_pod_get_double',['../group__spa__pod.html#gaa2a0b63cc84967f45561da19d420182d',1,'iter.h']]],
  ['spa_5fpod_5fget_5ffd_231',['spa_pod_get_fd',['../group__spa__pod.html#ga86cb2bcc11e2f431ba87fcdab9f5f58b',1,'iter.h']]],
  ['spa_5fpod_5fget_5ffloat_232',['spa_pod_get_float',['../group__spa__pod.html#ga6454e8f10d6a5b8d6d413b1b23134549',1,'iter.h']]],
  ['spa_5fpod_5fget_5ffraction_233',['spa_pod_get_fraction',['../group__spa__pod.html#ga3644f6f4720c7e2ee8eec3b7c22f9055',1,'iter.h']]],
  ['spa_5fpod_5fget_5fid_234',['spa_pod_get_id',['../group__spa__pod.html#ga5cac6d93f665bb39f005ed94a3b253e9',1,'iter.h']]],
  ['spa_5fpod_5fget_5fint_235',['spa_pod_get_int',['../group__spa__pod.html#ga0c2d7bbb354af62206cb8775a639988d',1,'iter.h']]],
  ['spa_5fpod_5fget_5flong_236',['spa_pod_get_long',['../group__spa__pod.html#ga9382aceb62c82555c3e3223fa0da4d16',1,'iter.h']]],
  ['spa_5fpod_5fget_5fpointer_237',['spa_pod_get_pointer',['../group__spa__pod.html#ga2a5fc72e003fbde4fdf58a4877aee59c',1,'iter.h']]],
  ['spa_5fpod_5fget_5frectangle_238',['spa_pod_get_rectangle',['../group__spa__pod.html#ga82aaa527c390ad8839f4aa165975b307',1,'iter.h']]],
  ['spa_5fpod_5fget_5fstring_239',['spa_pod_get_string',['../group__spa__pod.html#ga9d5776b990a068561a318deec6accd74',1,'iter.h']]],
  ['spa_5fpod_5fget_5fvalues_240',['spa_pod_get_values',['../group__spa__pod.html#gaa0eed1dfbff49bca1369a5c5f31fad39',1,'iter.h']]],
  ['spa_5fpod_5fis_5farray_241',['spa_pod_is_array',['../group__spa__pod.html#gabdf4cf3b06db29337cd7afdcaa29ddba',1,'iter.h']]],
  ['spa_5fpod_5fis_5fbitmap_242',['spa_pod_is_bitmap',['../group__spa__pod.html#ga01377325809bfef64781d29cd43d562a',1,'iter.h']]],
  ['spa_5fpod_5fis_5fbool_243',['spa_pod_is_bool',['../group__spa__pod.html#gafdfd0a7b261b3fc146b9820eeb4bb729',1,'iter.h']]],
  ['spa_5fpod_5fis_5fbytes_244',['spa_pod_is_bytes',['../group__spa__pod.html#ga1f1a0ba4321b3b36374ec01dcb9f5278',1,'iter.h']]],
  ['spa_5fpod_5fis_5fchoice_245',['spa_pod_is_choice',['../group__spa__pod.html#ga9c600d17cc240567be847b7f5f586bee',1,'iter.h']]],
  ['spa_5fpod_5fis_5fdouble_246',['spa_pod_is_double',['../group__spa__pod.html#gac52300de7f13278bfda13cc8d16d670a',1,'iter.h']]],
  ['spa_5fpod_5fis_5ffd_247',['spa_pod_is_fd',['../group__spa__pod.html#ga4af52f5f7810c61ad0b31baa8ab89632',1,'iter.h']]],
  ['spa_5fpod_5fis_5ffixated_248',['spa_pod_is_fixated',['../group__spa__pod.html#ga97c73044f717933b8df8f254288d9c1d',1,'iter.h']]],
  ['spa_5fpod_5fis_5ffloat_249',['spa_pod_is_float',['../group__spa__pod.html#gaee62f2962896bd0201a33586b40892f1',1,'iter.h']]],
  ['spa_5fpod_5fis_5ffraction_250',['spa_pod_is_fraction',['../group__spa__pod.html#gae4c5c97fe49fbdf5904f2763069ba3b4',1,'iter.h']]],
  ['spa_5fpod_5fis_5fid_251',['spa_pod_is_id',['../group__spa__pod.html#gac0b2f882008fa0493e6baf8283de6289',1,'iter.h']]],
  ['spa_5fpod_5fis_5finside_252',['spa_pod_is_inside',['../group__spa__pod.html#ga7c1572b9aa18a527d1e3e170fa5dbff9',1,'iter.h']]],
  ['spa_5fpod_5fis_5fint_253',['spa_pod_is_int',['../group__spa__pod.html#gacd6d3f0ac979a45184017b64e73f0917',1,'iter.h']]],
  ['spa_5fpod_5fis_5flong_254',['spa_pod_is_long',['../group__spa__pod.html#ga17a44ecdb496ac51492a2031620a9653',1,'iter.h']]],
  ['spa_5fpod_5fis_5fnone_255',['spa_pod_is_none',['../group__spa__pod.html#gade73b5e7c074fac279c18a325d894a71',1,'iter.h']]],
  ['spa_5fpod_5fis_5fobject_256',['spa_pod_is_object',['../group__spa__pod.html#ga81a0efc821fbd7906e1a7f3f9938533c',1,'iter.h']]],
  ['spa_5fpod_5fis_5fobject_5fid_257',['spa_pod_is_object_id',['../group__spa__pod.html#ga61b9eca25d1e870703142d964719fb59',1,'iter.h']]],
  ['spa_5fpod_5fis_5fobject_5ftype_258',['spa_pod_is_object_type',['../group__spa__pod.html#gabb298d1495a20cfdcf4f1f38e96fca5b',1,'iter.h']]],
  ['spa_5fpod_5fis_5fpointer_259',['spa_pod_is_pointer',['../group__spa__pod.html#ga54fd83598ec4391b5fcaa035a669874b',1,'iter.h']]],
  ['spa_5fpod_5fis_5frectangle_260',['spa_pod_is_rectangle',['../group__spa__pod.html#ga4ab6c61f2f16d5e5ab316db436f4e6d8',1,'iter.h']]],
  ['spa_5fpod_5fis_5fsequence_261',['spa_pod_is_sequence',['../group__spa__pod.html#ga8c99149486077bb1c281701b8fab1a7f',1,'iter.h']]],
  ['spa_5fpod_5fis_5fstring_262',['spa_pod_is_string',['../group__spa__pod.html#ga96ef2d603e6d18b3b461c0f0ee785283',1,'iter.h']]],
  ['spa_5fpod_5fis_5fstruct_263',['spa_pod_is_struct',['../group__spa__pod.html#ga881cb54fc6b73cc389ce7f43e84ecd26',1,'iter.h']]],
  ['spa_5fpod_5fnext_264',['spa_pod_next',['../group__spa__pod.html#ga44d25c0de11b0d4b7e5a233aa944d54c',1,'iter.h']]],
  ['spa_5fpod_5fobject_5ffind_5fprop_265',['spa_pod_object_find_prop',['../group__spa__pod.html#ga244df75ff8c63b2074bc803df3285de6',1,'iter.h']]],
  ['spa_5fpod_5fobject_5ffixate_266',['spa_pod_object_fixate',['../group__spa__pod.html#ga77978a8da43cf2f3bc74c086b046ceb0',1,'iter.h']]],
  ['spa_5fpod_5fobject_5fis_5ffixated_267',['spa_pod_object_is_fixated',['../group__spa__pod.html#gae055e56cab8d9ce9a6144874cbdbc606',1,'iter.h']]],
  ['spa_5fpod_5fparser_5fadvance_268',['spa_pod_parser_advance',['../group__spa__pod.html#ga95a24dd82b1909c1438b811c41019e30',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fcan_5fcollect_269',['spa_pod_parser_can_collect',['../group__spa__pod.html#gadc0c645fe393cbf90e92893207b356bf',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fcurrent_270',['spa_pod_parser_current',['../group__spa__pod.html#ga4257244263c5cecd126992569265525c',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fderef_271',['spa_pod_parser_deref',['../group__spa__pod.html#ga79e08a86ad91ae0e0898a7b3041fa33a',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fframe_272',['spa_pod_parser_frame',['../group__spa__pod.html#gab5f325e540bbe89f7afbc86c4ff39dbd',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fget_273',['spa_pod_parser_get',['../group__spa__pod.html#ga3fee24722968e95e0452012d0496c351',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fget_5fbool_274',['spa_pod_parser_get_bool',['../group__spa__pod.html#ga9871a0a457f1c1b6c88bb4fabe2a59e8',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fget_5fbytes_275',['spa_pod_parser_get_bytes',['../group__spa__pod.html#ga2d6f05e6d04867d1635b2f49fe1e5924',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fget_5fdouble_276',['spa_pod_parser_get_double',['../group__spa__pod.html#ga0effbdc0cb617d12faafae6956e78344',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fget_5ffd_277',['spa_pod_parser_get_fd',['../group__spa__pod.html#gaa7ef713efb4ce6e7a49b4f3dcb9ba921',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fget_5ffloat_278',['spa_pod_parser_get_float',['../group__spa__pod.html#ga20146fdbbe61b2f25c42aa651874c0c5',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fget_5ffraction_279',['spa_pod_parser_get_fraction',['../group__spa__pod.html#gaeb21751483ea18549318af4ef7375274',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fget_5fid_280',['spa_pod_parser_get_id',['../group__spa__pod.html#gabdf6e06a4b3861a11841166dff9d04c3',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fget_5fint_281',['spa_pod_parser_get_int',['../group__spa__pod.html#ga65b0bc2f897e44a0f2685ac5b498b9e1',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fget_5flong_282',['spa_pod_parser_get_long',['../group__spa__pod.html#ga5d25e015d753f88a4e272a4d007ec7fd',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fget_5fpod_283',['spa_pod_parser_get_pod',['../group__spa__pod.html#ga68d0832191b6f79f549735027d824632',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fget_5fpointer_284',['spa_pod_parser_get_pointer',['../group__spa__pod.html#gab23072b3f0f817478e011658b3504161',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fget_5frectangle_285',['spa_pod_parser_get_rectangle',['../group__spa__pod.html#ga7fda864b19555161ffa6b0bce9045fa8',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fget_5fstate_286',['spa_pod_parser_get_state',['../group__spa__pod.html#ga78e4ab314854074b4dd30344de63077b',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fget_5fstring_287',['spa_pod_parser_get_string',['../group__spa__pod.html#ga7c658bc2f25b9a3271292df883a16cd7',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fgetv_288',['spa_pod_parser_getv',['../group__spa__pod.html#gabd77500f3d51263793922aa4144b69a2',1,'parser.h']]],
  ['spa_5fpod_5fparser_5finit_289',['spa_pod_parser_init',['../group__spa__pod.html#ga9744b7a63e4be07f5a3da1428066c4c4',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fnext_290',['spa_pod_parser_next',['../group__spa__pod.html#ga8fe7f96447b154a8b0d3de31dba55adc',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fpod_291',['spa_pod_parser_pod',['../group__spa__pod.html#ga0b94ddcb6ab81c4f5e452a6377393798',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fpop_292',['spa_pod_parser_pop',['../group__spa__pod.html#gaec011820be5aaf92c14634e5a7d0d8fa',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fpush_293',['spa_pod_parser_push',['../group__spa__pod.html#ga96e7e55b25c16bec37945b6e960a2d17',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fpush_5fobject_294',['spa_pod_parser_push_object',['../group__spa__pod.html#ga80c5ed3cda1e515557a76c920fcb47fe',1,'parser.h']]],
  ['spa_5fpod_5fparser_5fpush_5fstruct_295',['spa_pod_parser_push_struct',['../group__spa__pod.html#ga72967636bbc40a10041c9b78537fdfb3',1,'parser.h']]],
  ['spa_5fpod_5fparser_5freset_296',['spa_pod_parser_reset',['../group__spa__pod.html#gad40a539793b9fcb49ce5993002db8241',1,'parser.h']]],
  ['spa_5fpod_5fprop_5ffirst_297',['spa_pod_prop_first',['../group__spa__pod.html#gacc743b22b0107a1b0f4311539ca395a6',1,'iter.h']]],
  ['spa_5fpod_5fprop_5fis_5finside_298',['spa_pod_prop_is_inside',['../group__spa__pod.html#gaff752dbb4e7a42857fac48cba26a5e71',1,'iter.h']]],
  ['spa_5fpod_5fprop_5fnext_299',['spa_pod_prop_next',['../group__spa__pod.html#gab54ebaf45ffc4ff7e9cf126bdf215e58',1,'iter.h']]],
  ['spa_5fprocess_5flatency_5fbuild_300',['spa_process_latency_build',['../group__spa__param.html#ga4e1fef404a8c1ac8da2e2d52c296f371',1,'latency-utils.h']]],
  ['spa_5fprocess_5flatency_5finfo_5fadd_301',['spa_process_latency_info_add',['../group__spa__param.html#gaa155862a8c38ee6bec331f05a7d0a760',1,'latency-utils.h']]],
  ['spa_5fprocess_5flatency_5fparse_302',['spa_process_latency_parse',['../group__spa__param.html#gaa39965cb137d66cef7816d3066356472',1,'latency-utils.h']]],
  ['spa_5fresult_5ffunc_5fdevice_5fparams_303',['spa_result_func_device_params',['../group__spa__device.html#gafaeb4b272c4322e31836412c4a0c2f74',1,'utils.h']]],
  ['spa_5fresult_5ffunc_5fnode_5fparams_304',['spa_result_func_node_params',['../group__spa__node.html#ga220a50a12909fbe19a2738fa17658235',1,'utils.h']]],
  ['spa_5fringbuffer_5fget_5fread_5findex_305',['spa_ringbuffer_get_read_index',['../group__spa__ringbuffer.html#gaa7b051ad6a9926f26522dda14555aa9e',1,'ringbuffer.h']]],
  ['spa_5fringbuffer_5fget_5fwrite_5findex_306',['spa_ringbuffer_get_write_index',['../group__spa__ringbuffer.html#gae84a3778b64a5e9dbccb8f75b50e3f99',1,'ringbuffer.h']]],
  ['spa_5fringbuffer_5finit_307',['spa_ringbuffer_init',['../group__spa__ringbuffer.html#ga23b552aedb20b289ff75899644363a15',1,'ringbuffer.h']]],
  ['spa_5fringbuffer_5fread_5fdata_308',['spa_ringbuffer_read_data',['../group__spa__ringbuffer.html#ga2e55c1d2e6fc8f11ae921ab54c6c4829',1,'ringbuffer.h']]],
  ['spa_5fringbuffer_5fread_5fupdate_309',['spa_ringbuffer_read_update',['../group__spa__ringbuffer.html#ga3fc30da551d1d6b3e29d875380b3e57e',1,'ringbuffer.h']]],
  ['spa_5fringbuffer_5fset_5favail_310',['spa_ringbuffer_set_avail',['../group__spa__ringbuffer.html#ga21c5ca3c2ac3c75f19c39e2dfef3611a',1,'ringbuffer.h']]],
  ['spa_5fringbuffer_5fwrite_5fdata_311',['spa_ringbuffer_write_data',['../group__spa__ringbuffer.html#ga9fa1f1070b14a85a4898f578a6bc9171',1,'ringbuffer.h']]],
  ['spa_5fringbuffer_5fwrite_5fupdate_312',['spa_ringbuffer_write_update',['../group__spa__ringbuffer.html#ga855a555fdb8afc184899dffbae165f82',1,'ringbuffer.h']]],
  ['spa_5fscnprintf_313',['spa_scnprintf',['../group__spa__string.html#gae194d9bc956defbfe180dc658e3df052',1,'string.h']]],
  ['spa_5fstrbuf_5fappend_314',['spa_strbuf_append',['../group__spa__string.html#ga921ebca10b8f1bacd31e159f11e96288',1,'string.h']]],
  ['spa_5fstrbuf_5finit_315',['spa_strbuf_init',['../group__spa__string.html#gab07cd1b0bb6923da2e15fe6eb018c7df',1,'string.h']]],
  ['spa_5fstrendswith_316',['spa_strendswith',['../group__spa__string.html#ga7f9387d004bd1dde300f434f2987e58e',1,'string.h']]],
  ['spa_5fstreq_317',['spa_streq',['../group__spa__string.html#gaccfedc485cb2e3bef649e77ee6db26ab',1,'string.h']]],
  ['spa_5fstrneq_318',['spa_strneq',['../group__spa__string.html#ga8a13832c182bd96cdeb32e93d0a5f4cf',1,'string.h']]],
  ['spa_5fstrstartswith_319',['spa_strstartswith',['../group__spa__string.html#ga0d201c72eaebf5c235c2c1790ca6da4e',1,'string.h']]],
  ['spa_5fstrtod_320',['spa_strtod',['../group__spa__string.html#ga0faf9c1cc2f41796a16399193bbdb263',1,'string.h']]],
  ['spa_5fstrtof_321',['spa_strtof',['../group__spa__string.html#ga928368a5adc237123fe3097ddf09061d',1,'string.h']]],
  ['spa_5fsupport_5ffind_322',['spa_support_find',['../group__spa__handle.html#ga82f1b02dfb782a24ed624e16392b1e12',1,'plugin.h']]],
  ['spa_5ftag_5fbuild_5fadd_5fdict_323',['spa_tag_build_add_dict',['../group__spa__param.html#ga26332db17a2bed2c5c31e5caede8abd9',1,'tag-utils.h']]],
  ['spa_5ftag_5fbuild_5fadd_5finfo_324',['spa_tag_build_add_info',['../group__spa__param.html#ga1602a3816a886eeab96eb1ab406716cb',1,'tag-utils.h']]],
  ['spa_5ftag_5fbuild_5fend_325',['spa_tag_build_end',['../group__spa__param.html#gaa8449e57ee4b6dcbb10b4c50bfe1ece3',1,'tag-utils.h']]],
  ['spa_5ftag_5fbuild_5fstart_326',['spa_tag_build_start',['../group__spa__param.html#ga74e9b5d6d1fbb7e80ed057205c8de6de',1,'tag-utils.h']]],
  ['spa_5ftag_5fcompare_327',['spa_tag_compare',['../group__spa__param.html#ga2a103e1a6794f27fe3c0b3b8d08f28d2',1,'tag-utils.h']]],
  ['spa_5ftag_5finfo_5fparse_328',['spa_tag_info_parse',['../group__spa__param.html#ga6fe291b7706101915cde605fc59d26a8',1,'tag-utils.h']]],
  ['spa_5ftag_5fparse_329',['spa_tag_parse',['../group__spa__param.html#ga673a6e3bccba9de900282c09b882a87d',1,'tag-utils.h']]],
  ['spa_5fthread_5futils_5facquire_5frt_330',['spa_thread_utils_acquire_rt',['../group__spa__thread.html#ga087f55566e08c2bb1536574b7556a66f',1,'thread.h']]],
  ['spa_5fthread_5futils_5fcreate_331',['spa_thread_utils_create',['../group__spa__thread.html#ga7c5acfdece976cd3f7b12dee4ddb3e41',1,'thread.h']]],
  ['spa_5fthread_5futils_5fdrop_5frt_332',['spa_thread_utils_drop_rt',['../group__spa__thread.html#gae1224b4702957d8a48f7c17cf350f5a2',1,'thread.h']]],
  ['spa_5fthread_5futils_5fget_5frt_5frange_333',['spa_thread_utils_get_rt_range',['../group__spa__thread.html#ga13cf7d6799ad80fe7e3f69874032d529',1,'thread.h']]],
  ['spa_5fthread_5futils_5fjoin_334',['spa_thread_utils_join',['../group__spa__thread.html#ga8dcf8fcd02dbf3c2c49afe37e40b6a43',1,'thread.h']]],
  ['spa_5ftype_5fis_5fa_335',['spa_type_is_a',['../group__spa__types.html#ga35e8b94254c7e556e3838eb8ab5167c3',1,'type-info.h']]],
  ['spa_5fvscnprintf_336',['spa_vscnprintf',['../group__spa__string.html#gab9f2fbcc3c33f77f37e9f00941f387b6',1,'string.h']]]
];
